@@ -5,7 +5,11 @@
 """
     FAX.PLUS REST API
 
-    OpenAPI spec version: 1.2.0
+    Visit https://apidoc.fax.plus for more information.
+
+    © Alohi SA (Geneva, Switzerland)
+
+    https://www.alohi.com
     Contact: info@fax.plus
 """
 
@@ -17,6 +21,7 @@ from faxplus.api.archives_api import ArchivesApi
 from faxplus.api.files_api import FilesApi
 from faxplus.api.numbers_api import NumbersApi
 from faxplus.api.outbox_api import OutboxApi
+from faxplus.api.webhooks_api import WebhooksApi
 # import ApiClient
 from faxplus.api_client import ApiClient
 from faxplus.configuration import Configuration
@@ -70,4 +75,12 @@ from faxplus.models.payload_outbox_comment import PayloadOutboxComment
 from faxplus.models.payload_outbox_modification import PayloadOutboxModification
 from faxplus.models.payload_outbox_options import PayloadOutboxOptions
 from faxplus.models.retry_options import RetryOptions
+from faxplus.models.send_fax_response import SendFaxResponse
 from faxplus.models.slack_notification_mode import SlackNotificationMode
+from faxplus.models.webhook import Webhook
+from faxplus.models.webhook_callback import WebhookCallback
+from faxplus.models.webhook_callback_data import WebhookCallbackData
+from faxplus.models.webhook_callback_hook import WebhookCallbackHook
+from faxplus.models.webhook_event_type import WebhookEventType
+from faxplus.models.webhook_id import WebhookId
+from faxplus.models.webhook_list import WebhookList
