@@ -3,7 +3,11 @@
 """
     FAX.PLUS REST API
 
-    OpenAPI spec version: 1.2.0
+    Visit https://apidoc.fax.plus for more information.
+
+    © Alohi SA (Geneva, Switzerland)
+
+    https://www.alohi.com
     Contact: info@fax.plus
 """
 
@@ -20,6 +24,10 @@ class FaxStatus(str, Enum):
     INSUFFICIENT_CREDIT = "insufficient_credit",
     FAILED = "failed",
     FAILED_INTERNAL_PROCESS_ERROR = "failed_internal_process_error",
+    FAILED_USER_BUSY = "failed_user_busy",
+    FAILED_NO_ANSWER = "failed_no_answer",
+    FAILED_UNALLOCATED_NUMBER = "failed_unallocated_number",
+    FAILED_OFFICE_CONVERTER_ISSUE = "failed_office_converter_issue",
     FAILED_SEPARATE_FILE_PAGES_ISSUE = "failed_separate_file_pages_issue",
     FAILED_RENDER_HEADER_ISSUE = "failed_render_header_issue",
     FAILED_INVALID_NUMBER_FORMAT = "failed_invalid_number_format",
