@@ -3,7 +3,11 @@
 """
     FAX.PLUS REST API
 
-    OpenAPI spec version: 1.2.0
+    Visit https://apidoc.fax.plus for more information.
+
+    © Alohi SA (Geneva, Switzerland)
+
+    https://www.alohi.com
     Contact: info@fax.plus
 """
 
@@ -12,7 +16,7 @@ from enum import Enum
 
 class NumberStatus(str, Enum):
     """
-    Status of your fax phone number e.g. active, inactive.
+    Status of your fax number e.g. active, inactive.
     """
     WAITING_VERIFICATION = "waiting_verification",
     ACTIVE = "active"
